==> ui-18.0.1.tgz: package/components/image/Image.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useRef } from 'react';
import { useForceUpdate } from '@react-devui/hooks';
import { getClassName } from '@react-devui/utils';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DImagePreview } from './ImagePreview';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DImage' });
export const DImage = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dLoading, dError, dActions, dImgProps } = _a, restProps = __rest(_a, ["dLoading", "dError", "dActions", "dImgProps"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const dataRef = useRef({
        isLoading: true,
        isError: false,
    });
    const forceUpdate = useForceUpdate();
    if (dImgProps.src !== dataRef.current.prevSrc) {
        dataRef.current.prevSrc = dImgProps.src;
        dataRef.current.isLoading = true;
        dataRef.current.isError = false;
    }
    return (_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}image`) }, { children: [dataRef.current.isLoading && dLoading, dataRef.current.isError && dError, 
            // eslint-disable-next-line jsx-a11y/alt-text
            _jsx("img", Object.assign({}, dImgProps, { style: Object.assign(Object.assign({}, dImgProps.style), { display: (dataRef.current.isLoading && dLoading) || (dataRef.current.isError && dError) ? 'none' : undefined }), onLoadStart: (e) => {
                    var _a;
                    // https://bugs.chromium.org/p/chromium/issues/detail?id=458851
                    (_a = dImgProps.onLoadStart) === null || _a === void 0 ? void 0 : _a.call(dImgProps, e);
                    dataRef.current.isLoading = true;
                    forceUpdate();
                }, onLoad: (e) => {
                    var _a;
                    (_a = dImgProps.onLoad) === null || _a === void 0 ? void 0 : _a.call(dImgProps, e);
                    dataRef.current.isLoading = false;
                    forceUpdate();
                }, onError: (e) => {
                    var _a;
                    (_a = dImgProps.onError) === null || _a === void 0 ? void 0 : _a.call(dImgProps, e);
                    dataRef.current.isLoading = false;
                    dataRef.current.isError = true;
                    forceUpdate();
                } })), dActions && (_jsx("div", Object.assign({ className: `${dPrefix}image__actions` }, { children: React.Children.map(dActions, (action) => cloneHTMLElement(action, {
                    className: getClassName(action.props.className, `${dPrefix}image__action`),
                })) })))] })));
};
DImage.Preview = DImagePreview;

==> ui-18.5.10.tgz: package/components/image/Image.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useRef } from 'react';
import { useForceUpdate } from '@react-devui/hooks';
import { getClassName } from '@react-devui/utils';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DImageAction } from './ImageAction';
import { DImagePreview } from './ImagePreview';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DImage' });
export const DImage = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dLoading, dError, dActions, dImgProps } = _a, restProps = __rest(_a, ["dLoading", "dError", "dActions", "dImgProps"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const dataRef = useRef({
        isLoading: true,
        isError: false,
    });
    const forceUpdate = useForceUpdate();
    if (dImgProps.src !== dataRef.current.prevSrc) {
        dataRef.current.prevSrc = dImgProps.src;
        dataRef.current.isLoading = true;
        dataRef.current.isError = false;
    }
    return (_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}image`) }, { children: [dataRef.current.isLoading && dLoading, dataRef.current.isError && dError, 
            // eslint-disable-next-line jsx-a11y/alt-text
            _jsx("img", Object.assign({}, dImgProps, { style: Object.assign(Object.assign({}, dImgProps.style), { display: (dataRef.current.isLoading && dLoading) || (dataRef.current.isError && dError) ? 'none' : undefined }), onLoadStart: (e) => {
                    var _a;
                    // https://bugs.chromium.org/p/chromium/issues/detail?id=458851
                    (_a = dImgProps.onLoadStart) === null || _a === void 0 ? void 0 : _a.call(dImgProps, e);
                    dataRef.current.isLoading = true;
                    forceUpdate();
                }, onLoad: (e) => {
                    var _a;
                    (_a = dImgProps.onLoad) === null || _a === void 0 ? void 0 : _a.call(dImgProps, e);
                    dataRef.current.isLoading = false;
                    forceUpdate();
                }, onError: (e) => {
                    var _a;
                    (_a = dImgProps.onError) === null || _a === void 0 ? void 0 : _a.call(dImgProps, e);
                    dataRef.current.isLoading = false;
                    dataRef.current.isError = true;
                    forceUpdate();
                } })), dActions && _jsx("div", Object.assign({ className: `${dPrefix}image__actions` }, { children: React.Children.map(dActions, (action) => action) }))] })));
};
DImage.Action = DImageAction;
DImage.Preview = DImagePreview;
